@@ -112,11 +112,14 @@ class Database:
 
     def __getattr__(self, name):
         if self.__connection is None:
-            self.__connection = self.__factory(*self.__args, **self.__keywords)
-            logger = logging.getLogger(__name__)
-            logger.debug('opening %s', self.__class__.__name__)
+            self.connect()
         return getattr(self.__connection, name)
 
+    def connect(self):
+        self.__connection = self.__factory(*self.__args, **self.__keywords)
+        logger = logging.getLogger(__name__)
+        logger.debug('opening %s', self.__class__.__name__)
+
     def translate(self, command, *args, many=False):
         """translate sql dialects
 
@@ -287,11 +290,18 @@ class Database:
             logger.error(msg)
             raise DatabaseException(msg)
 
+    def _use(self, **kwargs):
+        params = dict(
+            self.__keywords, **kwargs
+        )
+        return type(self)(*self.__args, **params)
+
     def use(self, name):
         """use another database on the same instance"""
-        args = list(self.__args)
-        keywords = dict(self.__keywords, db=name)
-        return type(self)(*args, **keywords)
+        return self._use(db=name)
+        # args = list(self.__args)
+        # keywords = dict(self.__keywords, db=name)
+        # return type(self)(*args, **keywords)
 
     def report(self):   # pragma: no cover
         """produce a SQL log report"""
@@ -310,9 +320,28 @@ class Database:
         del cls.stats[:len(result)]  # clear the list, but more may have been added
         return result
 
+    @property
+    def database_names(self):
+        """Return list of database names"""
+        return self.get_database_names()
+
     def get_table_names(self):
         """get list of database tables"""
 
+
+    def get_schema_names(self):
+        """Return schema names"""
+        return []
+
+    @property
+    def schema_names(self):
+        return self.get_schema_names()
+
+    @property
+    def table_names(self):
+        """Return list of table names"""
+        return self.get_table_names()
+
     @property
     def database(self):
         """Returns an object containing database parameters"""
@@ -331,3 +360,13 @@ class Database:
         logger.debug('closing %s connection',
             self.__class__.__name__)
         self.close()
+
+    def get_connection(self):
+        return self.__connection
+
+    def get_args(self):
+        return self.__args
+
+    def get_kwargs(self):
+        return self.__keywords
+
