@@ -481,6 +481,8 @@ class ItemList(list):
         def nvl(value):
             if value is None:
                 return 'None'
+            elif isinstance(value, str):
+                return value.strip()
             return value
 
         if len(self) == 0:
@@ -639,7 +641,7 @@ class RecordList(list):
         """
 
         def visible(name):
-            return not name.startswith('__')
+            return not name.startswith('__') and not name in getattr(self[0], 'hidden', [])
 
         if not bool(self):
             return 'Empty list'
